#[non_exhaustive]
pub enum Request { Destroy, GrabKeyboard { id: New<ZwpXwaylandKeyboardGrabV1>, surface: WlSurface, seat: WlSeat, }, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Destroy

destroy the keyboard grab manager

Destroy the keyboard grab manager.

This is a destructor, once received this object cannot be used any longer.



GrabKeyboard

grab the keyboard to a surface

The grab_keyboard request asks for a grab of the keyboard, forcing the keyboard focus for the given seat upon the given surface.

The protocol provides no guarantee that the grab is ever satisfied, and does not require the compositor to send an error if the grab cannot ever be satisfied. It is thus possible to request a keyboard grab that will never be effective.

The protocol:

  • does not guarantee that the grab itself is applied for a surface, the grab request may be silently ignored by the compositor,
  • does not guarantee that any events are sent to this client even if the grab is applied to a surface,
  • does not guarantee that events sent to this client are exhaustive, a compositor may filter some events for its own consumption,
  • does not guarantee that events sent to this client are continuous, a compositor may change and reroute keyboard events while the grab is nominally active.

Fields

surface: WlSurface

surface to report keyboard events to

seat: WlSeat

the seat for which the keyboard should be grabbed

Implementations



impl Request

pub fn opcode(&self) -> u16

Get the opcode number of this message